import { Account, Announcement, Company, Conversation, ConversationPrompt } from "./data";

export const MOCK_ANNOUNCEMENTS: Announcement[] = [
    new Announcement({
        status: 'primary',
        message: 'Primary',
    }),
    new Announcement({
        status: 'warning',
        message: 'Warning',
    }),
    new Announcement({
        status: 'info',
        message: 'Info',
    })
    ,
    new Announcement({
        status: 'light',
        message: 'Light',
    })
    ,
    new Announcement({
        status: 'dark',
        message: 'Dark',
    })
    ,
    new Announcement({
        status: 'success',
        message: 'success',
    })
    ,
    new Announcement({
        status: 'danger',
        message: 'Danger',
    })
    ,
    new Announcement({
        status: 'secondary',
        message: 'Secondary',
    })
]

export const MOCK_COMPANY: Company[] = [
    new Company({
        id: 0,
        name: "Company A",
        state: 'IL',
        zipcode: 60189,
        address: '123 Something'
    }),
    new Company({
        id: 1,
        name: "Company B",
        state: 'OH',
        zipcode: 44512,
        address: '91235 Boardwalk'
    })
]

export const MOCK_ACCOUNTS: Account[] = [
    new Account({
        email: 'rufus.t.firefly@newtonia.com',
        first_name: 'Rufus',
        last_name: 'Firefly',
        role: 'company manager',
        company: MOCK_COMPANY[0]
        
    }),
    new Account({
        email: 'something@something.com',
        first_name: 'Billy Bob',
        last_name: 'Thorton',
        role: 'user',
        company: MOCK_COMPANY[0]
    }),
    new Account({
        email: 'mom@mi6.com',
        first_name: 'Mallory',
        last_name: 'Something',
        role: 'company manager',
        company: MOCK_COMPANY[1]
        
    }),
    new Account({
        email: '007@mi6.com',
        first_name: 'James',
        last_name: 'Bond',
        role: 'user',
        company: MOCK_COMPANY[1]
    }),
]

export const MOCK_CONVESATION_DETAIL: ConversationPrompt[] = [
    new ConversationPrompt({
        id: 0,
        message: "Hello, World!",
    }),
    new ConversationPrompt({
        id:1,
        message: "Hello Dave",

    }),
    new ConversationPrompt({
        id: 2,
        message: "Can you help me with a math problem",
    }),
    new ConversationPrompt({
        id:3,
        message: "I cannot do that Dave",
    }),
    new ConversationPrompt({
        id: 4,
        message: "Let's start over",
    }),
    new ConversationPrompt({
        id:5,
        message: "Hello Dave",

    }),
    new ConversationPrompt({
        id: 6,
        message: "Can you help me with a math problem, pretty please",
    }),
    new ConversationPrompt({
        id:7,
        message: "Absolutely!",
    }),
    new ConversationPrompt({
        id: 8,
        message: "What is 2 + 2?",
    }),
    new ConversationPrompt({
        id: 9,
        message: "Dave, you didn't say please.",
    }),
    new ConversationPrompt({
        id: 10,
        message: "Fine. Please tell me what is 2 + 2",
    }),
    new ConversationPrompt({
        id:11,
        message: "4. 2 + 2 = 4.",
    }),
];

export const MOCK_CONVERSATION: Conversation[] = [
    new Conversation({
        id: 0,
        title: "First One",
        account: MOCK_ACCOUNTS[0]
    }),
    new Conversation({
        id: 1,
        title: "Math problem",
        account: MOCK_ACCOUNTS[0],
        conversationDetail: [
            ...MOCK_CONVESATION_DETAIL.slice(0,4) // update this to be a slice
        ],
    }),
    new Conversation({
        id: 2,
        title: "Math problem but nice",
        account: MOCK_ACCOUNTS[0],
        conversationDetail: [
            ...MOCK_CONVESATION_DETAIL.slice(4,12) // update this to be a slice
        ],
    }),
    new Conversation({
        id: 3,
        title: "Create Graph",
        account: MOCK_ACCOUNTS[0]
    }),
    new Conversation({
        id: 4,
        title: "Company Report",
        account: MOCK_ACCOUNTS[1]
    }),

]



/*  add more mockk data*/